﻿using System;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Media;
using Infragistics.Controls.Charts;

namespace GenerateChart
{
    public static class Chart
    {
        private static SimpleDataCollection dataCollection = new SimpleDataCollection(15,0);

        public static XamDataChart GetChart()
        {
            var chart = new XamDataChart();
            chart.Padding = new Thickness(35, 0, 40, 0);

            LinearGradientBrush lgb = new LinearGradientBrush();
            lgb.StartPoint =  new Point(0, 1);
            lgb.EndPoint = new Point(0, 0);
            GradientStop lightGreyGS = new GradientStop();
            lightGreyGS.Color = Colors.LightGray;
            lightGreyGS.Offset = 0.0;
            GradientStop whiteGS = new GradientStop();
            whiteGS.Color = Colors.White;
            whiteGS.Offset = 1.0;
            lgb.GradientStops.Add(lightGreyGS);
            lgb.GradientStops.Add(whiteGS);
            chart.PlotAreaBackground = lgb;

            var xAxis = new CategoryDateTimeXAxis();

            xAxis.MinorInterval = new TimeSpan(0, 2, 0, 0, 0);
            xAxis.MinorStrokeThickness = 1;
            xAxis.MinorStroke = Brushes.White;
            xAxis.MajorStroke = Brushes.Black;
            xAxis.Interval = new TimeSpan(1, 0, 0, 0, 0);
            xAxis.MajorStrokeThickness = 2;

            var yAxis = new NumericYAxis();
            yAxis.LabelSettings = new AxisLabelSettings();
            yAxis.LabelSettings.Margin = new Thickness(10);
            yAxis.MinimumValue = 0;
            yAxis.Interval = 5;
            yAxis.MaximumValue = 20;

            xAxis.ItemsSource = dataCollection;
            xAxis.DateTimeMemberPath = "Label";
            xAxis.Label = "{Label: dd-MMM-yy HH:ss}";


            chart.Axes.Add(xAxis);
            chart.Axes.Add(yAxis);


            DateTime thisDTM = dataCollection[3].Label.AddMinutes(10);
            dataCollection.Insert(4, new SimpleDataPoint() { Value = double.NaN, Label = thisDTM, ToolTip = "" });

            var series = new LineSeries();
                series.ValueMemberPath = "Value";
                series.ItemsSource = dataCollection;
                series.XAxis = xAxis;
                series.YAxis = yAxis;
   
                series.Brush = System.Windows.Media.Brushes.Orange;
                series.MarkerBrush = System.Windows.Media.Brushes.Orange;

                series.MarkerType = MarkerType.Square;
                series.ToolTip = GetTooltip();

                chart.Series.Add(series);
            
            return chart;
        }

        public static ContentControl GetTooltip()
        {
            ContentControl cc = new ContentControl();

            StackPanel ParentStack = new StackPanel();

            StackPanel YStack = new StackPanel() { Orientation = Orientation.Horizontal };
            TextBlock yValue = new TextBlock();
            yValue.SetBinding(TextBlock.TextProperty, new Binding("Item.ToolTip"));
            YStack.Children.Add(yValue);

            ParentStack.Children.Add(YStack);

            cc.Content = ParentStack;

            return cc;
        }

    }
}
