﻿using System.Windows;
using System.Windows.Controls;

namespace GenerateChart
{
    /// <summary>
    /// Behaves like a stackpanel except each element will fill the space available in the container
    /// like a grid/stackpanel hybrid
    /// </summary>
    public class CustomStackPanel : Panel
    {
        protected override Size MeasureOverride(Size availableSize)
        {
            int howManyVisible = 0;
            // Tell child they have as much height as they want
            for (int i = 0; i < InternalChildren.Count; i++)
            {
                if (InternalChildren[i].IsVisible)
                {
                    howManyVisible++;
                }
            }
            Size childSize = new Size(availableSize.Width, (availableSize.Height / howManyVisible)); //double.PositiveInfinity);

            // Calling Measure causes each child to set its DesiredSize property
            //foreach (UIElement elem in InternalChildren)
            //    elem.Measure(childSize);

            return availableSize;
        }

        protected override Size ArrangeOverride(Size finalSize)
        {
            Size childSize;
            int howManyVisible = 0;

            for (int i = 0; i < InternalChildren.Count; i++)
            {
                if (InternalChildren[i].IsVisible)
                {
                    howManyVisible++;
                }
            }

            double top = 0.0;
            for (int i = 0; i < InternalChildren.Count; i++)
            {
                // We force each child to full width, but let it
                // be at desired height
                if (InternalChildren[i].IsVisible)
                {
                    childSize = new Size(finalSize.Width, (finalSize.Height / howManyVisible));
                    Rect r = new Rect(new Point(0.0, top), childSize);
                    InternalChildren[i].Arrange(r);
                    top += childSize.Height;
                }

            }

            return finalSize;
        }
    }
}